# Nastavení disků v Linuxu

Tento dokument poskytuje podrobný návod, jak nastavit disky v Linuxovém systému. Obsahuje kroky pro kontrolu dostupných disků, vytvoření oddílů, formátování, připojení a nastavení oprávnění.

## 1. Kontrola dostupných disků

Než začnete s jakoukoli operací, je důležité zjistit, které disky jsou v systému dostupné. K tomu použijte příkaz `lsblk` nebo `fdisk -l`:

```bash
lsblk
```
nebo

```bash
sudo fdisk -l
```
Tyto příkazy zobrazí seznam všech dostupných disků a jejich oddílů.

## 2. Vytvoření nového oddílu

Pokud máte nový disk, který chcete použít, je třeba na něm vytvořit nový oddíl. K tomu můžete použít fdisk nebo gdisk:
Použití fdisk

```bash
sudo fdisk /dev/sdX
```

V fdisk použijte následující příkazy:

- `n` pro vytvoření nového oddílu
- `p` pro primární oddíl
-  Zadejte číslo oddílu (např. 1)
-  Zadejte výchozí hodnoty pro začátek a konec oddílu
- `w` pro zápis změn a ukončení

### Použití gdisk

```bash
sudo gdisk /dev/sdX
```

V gdisk použijte následující příkazy:

- `n` pro vytvoření nového oddílu
-  Zadejte číslo oddílu (např. 1)
-  Zadejte výchozí hodnoty pro začátek a konec oddílu
- `w` pro zápis změn a ukončení

## 3. Formátování oddílu

Po vytvoření nového oddílu jej musíte naformátovat na požadovaný souborový systém, například ext4:

```bash
sudo mkfs.ext4 /dev/sdX1
```

## 4. Připojení oddílu

Pro připojení nově vytvořeného a naformátovaného oddílu použijte příkaz mount. Nejprve vytvořte adresář, kam bude oddíl připojen:

```bash
sudo mkdir /mnt/novy_disk
```

Poté připojte oddíl:

```bash
sudo mount /dev/sdX1 /mnt/novy_disk
```

## 5. Nastavení oprávnění

Po připojení disku nastavte oprávnění, aby byl zapisovatelný. Použijte příkaz chmod pro změnu oprávnění:

```bash
sudo chmod -R 755 /mnt/novy_disk
```

Pokud chcete změnit vlastníka adresáře, použijte příkaz chown:

```bash
sudo chown -R uživatel:skupina /mnt/novy_disk
```

## 6. Automatické připojení při startu

Aby byl disk automaticky připojen při startu systému, upravte soubor /etc/fstab:

```bash
sudo nano /etc/fstab
/dev/sdX1 /mnt/novy_disk ext4 defaults 0 2
```

Tento záznam zajistí, že oddíl /dev/sdX1 bude připojen do /mnt/novy_disk při každém startu systému.
Shrnutí

Tento návod vás provede kroky potřebnými k nastavení nového disku v Linuxu, včetně kontroly dostupných disků, vytvoření a formátování oddílů, připojení a nastavení oprávnění. Pokud máte jakékoli dotazy nebo potřebujete další pomoc, neváhejte se obrátit na komunitu nebo dokumentaci.
